Structs
Enums
Functions
- process_
error - wasi_
preview1_ fd_ prestat_ dir_ name - This function is used to get the directory name of a file descriptor. It is used to get the directory name of a file descriptor. The file descriptor must be a directory.