Module wasi

Structs

FileType
Filestat

Enums

Fstflags
WasiError

Functions

process_error
wasi_preview1_fd_prestat_dir_name
This function is used to get the directory name of a file descriptor. It is used to get the directory name of a file descriptor. The file descriptor must be a directory.